'''
  Copyleft ITEG IT-Engineers GmbH 2021,2024
'''

import getopt
#import io
#import lxc
#import os
#import os.path
import subprocess
import sys

from iteg.pveutils import dto
from iteg.pveutils import puhelpers
from iteg.pveutils import pulogging

log = pulogging.getLogger()


def describeUsage(argv0):
    usage = ""
    usage += "Usage: %s [options...] containerIdOrName\n" % argv0
    usage += "\n"
    usage += "Executes a shell in the specified running PVE/LXC container.\n"
    usage += pulogging.getCommonUsageOptions()
    #usage += "  Specific options are:\n"
    #usage += "    -l        Use pveObject.attach_wait() instead of lxc-attach.\n"
    #usage += "              This might become the default without notice.\n"
    return usage


def run_pu_enter(argv0,args):
    
    try:
        opts, containerNames = getopt.getopt(args, "dhqtv", ["help"])
    except getopt.GetoptError as err:
        print(err, file=sys.stderr) # will print something like "option -a not recognized"
        print(describeUsage(argv0), file=sys.stderr)
        sys.exit(64)

    #useLxcObject = True

    for o, a in opts:
        if o in ["-d", "-q", "-t", "-v"]:
            continue
        elif o in ["-h" , "--help"]:
            print(describeUsage(argv0))
            sys.exit(0)
        else:
            log.warning("Unhandled option: %s %s" %
                  (o, a))
    
    puConfiguration = dto.PUConfiguration()
    
    if len(containerNames) != 1:
        log.error("Expecting exactly 1 container name, not %d." %
              len(containerNames))
        print(describeUsage(argv0), file=sys.stderr, flush=True)
        sys.exit(1)
     
    containerReference = containerNames[0]
    
    puContainer = puConfiguration.getContainer(containerReference)
    if puContainer == None:
        log.error("Unable to find PVE/LXC container with ID (or unique name part) %s" %
              containerReference)
        sys.exit(1)
    
    puhelpers.detectRunningContainers(puConfiguration=puConfiguration)
    if not puContainer.knownAsRunning:
        log.error("PVE/LXC container %s (%s) is not running, nothing to do?" %
              (puContainer.id, puContainer.hostname))
        sys.exit(1)

    rc = 0
    log.debug("Entering PVE/LXC container with %s (%s) lxc-attach -n %s ..." %
          (puContainer.id, puContainer.hostname, puContainer.id))
    cp = subprocess.run(["/usr/bin/lxc-attach", "-n", puContainer.id, "--", "/bin/bash"])
    rc = cp.returncode
    log.debug("Back from 'lxc-attach -n %s -- /bin/bash' with rc %d" % (
          puContainer.id, rc))

    sys.exit(rc)
