'''
  Copyleft ITEG IT-Engineers GmbH 2021,2024
'''

import getopt
#import io
#import lxc
#import os
#import os.path
#import re
#import subprocess
import sys

from iteg.pveutils import dto
from iteg.pveutils import puhelpers
from iteg.pveutils import pulogging

log = pulogging.getLogger()


def describeUsage(argv0):
    usage = ""
    usage += "Usage: %s [options...] containerIdOrName command [cmdOptions...]\n" % argv0
    usage += "\n"
    usage += "Preform the specifed command in the specified running PVE/LXC container.\n"
    usage += pulogging.getCommonUsageOptions()
    usage += "  Specific options are:\n"
    usage += "    -g grex   Grep printed stuff for 'grex' case insensitive. See warning below.\n"
    #usage += "    -l        Use pveObject.attach_wait(). This is the default now.\n"
    #usage += "    -L        Use legacy approach calling lxc-attach.\n"
    usage += "    -o file   Write stdout & stderr of command to specified container/host file.\n"
    usage += "              in addition to printing it. See warnings below.\n"
    usage += "    -w secs   Wait max. this many seconds, defaults to 0 (forever).\n"
    usage += "\n"
    usage += "Warning:\n"
    usage += "Options -g and -o trigger collection of all the command's stdout/stderr in RAM.\n"
    usage += "This suppresses immediate output of anything (like questions).\n"
    #usage += "\n"
    #usage += "Warning 2:\n"
    #usage += "The file for option -o is written in container context by default (see -l).\n"
    #usage += "Only if -L is specified the file is writting in host context.\n"
    return usage


def run_pu_exec(argv0,args):
    
    try:
        opts, containerNameAndCmd  = getopt.getopt(args, "dg:ho:qtvw:", ["help"])
    except getopt.GetoptError as err:
        print(err, file=sys.stderr) # will print something like "option -a not recognized"
        print(describeUsage(argv0), file=sys.stderr)
        sys.exit(64)

    #useLxcObject = True
    grepFor = ""
    waitMaxSeconds = -1
    teeFileName = ""

    for o, a in opts:
        if o in ["-d", "-q", "-t", "-v"]:
            continue
        elif o in ["-h" , "--help"]:
            print(describeUsage(argv0))
            sys.exit(0)
        elif o in ["-g"]:
            grepFor = str(a)
        elif o in ["-o"]:
            teeFileName = str(a)
        elif o in ["-w"]:
            waitMaxSeconds = int(a)
        else:
            log.warning("Unhandled option: %s %s" %
                  (o, a))
    
    puConfiguration = dto.PUConfiguration()

    if len(containerNameAndCmd) == 0:
        log.error("Expecting a container and a command, got neither.")
        print(describeUsage(argv0), file=sys.stderr, flush=True)
        sys.exit(1)
    if len(containerNameAndCmd) < 2:
        log.error("Expecting a container and a command, got no command.")
        print(describeUsage(argv0), file=sys.stderr, flush=True)
        sys.exit(1)
     
    containerReference = containerNameAndCmd[0]
    cmdParts = containerNameAndCmd[1:]
    
    puContainer = puConfiguration.getContainer(containerReference)
    if puContainer == None:
        log.error("Unable to find PVE/LXC container with ID (or unique name part) %s" %
              containerReference)
        sys.exit(1)
    
    puhelpers.detectRunningContainers(puConfiguration=puConfiguration)
    if not puContainer.knownAsRunning:
        log.error("PVE/LXC container %s (%s) is not running, nothing to do?" %
              (puContainer.id, puContainer.hostname))
        sys.exit(1)

    #log.debug("Executing %s in PVE/LXC container %s (%s) ..." %
    #          (cmdParts[0], puContainer.id, puContainer.hostname))
    
    rc = puhelpers.execInContainer(puContainer=puContainer, cmdParts=cmdParts, 
                                    grepFor=grepFor,
                                    waitMaxSeconds=waitMaxSeconds,
                                    teeFileName=teeFileName)

    #log.debug("Back from executing %s in PVE/LXC container %s (%s), exiting with rc %d." %
    #          (cmdParts[0], puContainer.id, puContainer.hostname, rc))
    sys.exit(rc)
