'''
  Copyleft ITEG IT-Engineers GmbH 2021,2024
'''

import getopt
#import io
#import lxc
#import os
#import os.path
#import re
#import subprocess
import sys

from iteg.pveutils import dto
from iteg.pveutils import puhelpers
from iteg.pveutils import pulogging

log = pulogging.getLogger()


def describeUsage(argv0):
    usage = ""
    usage += "Usage: %s [options...] command [cmdOptions...]\n" % argv0
    usage += "\n"
    usage += "Preforms the specifed command in all running PVE/LXC containers.\n"
    usage += pulogging.getCommonUsageOptions()
    usage += "  Specific options are:\n"
    usage += "    -g grex   Grep printed stuff for 'grex', case insensitive.\n"
    usage += "              Use with great care, grepping is done after command completion\n"
    usage += "              and all the command's stdout/stderr output is collected in RAM.\n"
    #usage += "    -l        Use pveObject.attach_wait(). This is the default now.\n"
    #usage += "    -L        Use legacy approach calling pve-attach.\n"
    usage += "    -p        Pause after each container.\n"
    usage += "    -w secs   Wait max. this many seconds, defaults to 0 (forever).\n"
    return usage


def run_pu_exec_in_all(argv0,args):
    
    try:
        opts, cmdParts = getopt.getopt(args, "dg:hpqtvw:", ["help"])
    except getopt.GetoptError as err:
        print(err, file=sys.stderr) # will print something like "option -a not recognized"
        print(describeUsage(argv0), file=sys.stderr)
        sys.exit(64)

    #useLxcObject = True
    grepFor = ""
    pauseAfterEach = False
    waitMaxSeconds = -1
    
    for o, a in opts:
        if o in ["-d", "-q", "-t", "-v"]:
            continue
        elif o in ["-h" , "--help"]:
            print(describeUsage(argv0))
            sys.exit(0)
        elif o in ["-g"]:
            grepFor = str(a)
        elif o in ["-p"]:
            pauseAfterEach = True
        elif o in ["-w"]:
            waitMaxSeconds = int(a)
        else:
            log.warning("Unhandled option: %s %s" %
                  (o, a))
    
    puConfiguration = dto.PUConfiguration()

    if len(cmdParts) < 1:
        log.error("Got no command to perform.")
        print(describeUsage(argv0), file=sys.stderr, flush=True)
        sys.exit(1)
    
    puhelpers.detectRunningContainers(puConfiguration=puConfiguration)
    
    if len(puConfiguration.runningContainers) == 0:
        if log.verbosity >= 3:
            log.warning("No PVE/LXC containers running.")
            sys.exit(0)

    rcSum = 0
    for runningCTName in sorted(puConfiguration.runningContainerNames):
        print("", file=sys.stdout) # empty line
        puContainer = puConfiguration.getContainer(runningCTName)
        log.notice("Calling for container %s (%s)" % 
                   (puContainer.id, puContainer.hostname))
        rc = puhelpers.execInContainer(puContainer=puContainer, cmdParts=cmdParts,
                                       grepFor=grepFor, waitMaxSeconds=waitMaxSeconds)
        rcSum += rc
        log.notice("Done for container %s (%s)\n" %
                   (puContainer.id, puContainer.hostname))
        if pauseAfterEach:
            try:
                input("Press enter to continue with next container.")
            except:
                print("\n", file=sys.stderr, flush=True)
                log.warning("Aborting after container %s (%s)" %
                            (puContainer.id, puContainer.hostname))
                sys.exit(1)
            log.notice("Continuing ...")

    log.debug("Exiting with rcSum %d" % rcSum)
    sys.exit(rcSum)
