'''
  Copyright ITEG IT-Engineers GmbH 2018,2024
'''

import getopt
#import lxc
#import os
import sys
#import configparser

#from clazzes.pbadownload import util
from iteg.pveutils import dto
from iteg.pveutils import puhelpers
from iteg.pveutils import pulogging

log = pulogging.getLogger()


def describeUsage(argv0):
    usage = ""
    usage += "Usage: %s [options...]\n" % argv0
    usage += "\n"
    usage += "Lists the resource consumption of all running PVE/LXC containers.\n"
    usage += "\n"
    usage += "Some values are collected from container start, some are current.\n"
    usage += "See man pve-info for details on some values.\n"
    usage += pulogging.getCommonUsageOptions()
    return usage


def run_pu_list_resources(argv0,args):
    
    try:
        opts, garbage = getopt.getopt(args, "dhqtv", ["help"])
    except getopt.GetoptError as err:
        print(err, file=sys.stderr) # will print something like "option -a not recognized"
        print(describeUsage(argv0), file=sys.stderr)
        sys.exit(64)

    for o, a in opts:
        if o in ["-d", "-q", "-t", "-v"]:
            continue
        elif o in ["-h" , "--help"]:
            print(describeUsage(argv0))
            sys.exit(0)
        else:
            log.warning("Unhandled option: %s %s" % (
                o, a))
    if len(garbage) > 0:
        log.warning("Unhandled options: %s" %
              " ".join(garbage))

    puConfiguration = dto.PUConfiguration()

    puhelpers.detectRunningContainers(puConfiguration=puConfiguration)
        
    if len(puConfiguration.runningContainers) == 0:
        if log.verbosity >= 3:
            log.warning("No PVE/LXC containers running.")
            sys.exit(0)

    for puContainer in puConfiguration.runningContainers:
        log.debug("Analysing running container %s" % puContainer)
        puhelpers.detectCurrentContainerResources(puContainer=puContainer)
    
    print("Container                       PID  CPU h  MBs Mem  KMem          TX        RX     Blk IO")
    print("------------------------------------------------------------------------------------------")
    for runningCTName in sorted(puConfiguration.runningContainerNames):
        puContainer = puConfiguration.getContainer(containerRef=runningCTName)
        print("%s %6d %s %s %s %s %s %s" %
              ('{0: <28}'.format(puContainer.id),
               puContainer.pid,     
               "{: >6}".format(int(puContainer.cpuUse/3600)),
               "{: >8,}".format(int(puContainer.memUse/1048576)).replace(",","."),
               "{: >5}".format(int(puContainer.kMemUse/1048576)),
               "{: >11,}".format(int(puContainer.txBytes/1048576)).replace(",","."),
               "{: >9,}".format(int(puContainer.rxBytes/1048576)).replace(",","."),
               "{: >10,}".format(int(puContainer.blkIoUse/1048576)).replace(",",".")
              ))
        '''
        print("{0: <28} {: >6} {: >13,} {: >17,} {: >13,} {: >13,} {: >13,} {: >13,}".format(
               pveContainer.id,
               pveContainer.pid,     
               pveContainer.cpuUse,
               pveContainer.memUse,
               pveContainer.kMemUse,
               pveContainer.txBytes,
               pveContainer.rxBytes,
               pveContainer.blkIoUse
              ).replace(",","."))
        '''
    
    sys.exit(0)
