'''
  Copyleft ITEG IT-Engineers GmbH 2021,2024
'''

import getopt
#import lxc
#import os
import sys

from iteg.pveutils import dto
from iteg.pveutils import puhelpers
from iteg.pveutils import pulogging

log = pulogging.getLogger()


def describeUsage(argv0):
    usage = ""
    usage += "Usage: %s [options...]\n" % argv0
    usage += "\n"
    usage += "Lists all running PVE/LXC containers' names to stdout.\n"
    usage += "\n"
    usage += "Do not use -h, --help, -d or -v when processing the output automatically.\n"
    usage += "\n"
    usage += "For some do-in-all-containers tasks look at pve-exec-in-all.\n"
    usage += "\n"
    usage += pulogging.getCommonUsageOptions()
    return usage


def run_pu_list_running(argv0,args):
    try:
        opts, garbage = getopt.getopt(args, "dhqtv", ["help"])
    except getopt.GetoptError as err:
        print(err, file=sys.stderr) # will print something like "option -a not recognized"
        print(describeUsage(argv0), file=sys.stderr)
        sys.exit(64)

    for o, a in opts:
        if o in ["-d", "-q", "-t", "-v"]:
            continue
        elif o in ["-h" , "--help"]:
            print(describeUsage(argv0))
            sys.exit(0)
        else:
            log.warning("Unhandled option: %s %s" % (
                o, a))
    if len(garbage) > 0:
        log.warning("Unhandled options: %s" %
              " ".join(garbage))

    puConfiguration = dto.PUConfiguration()

    puhelpers.detectRunningContainers(puConfiguration=puConfiguration)
        
    if len(puConfiguration.runningContainers) == 0:
        if log.verbosity >= 3:
            log.warning("No PVE/LXC containers running.")
            sys.exit(0)
    
    runningCTNames = []
    for puContainer in puConfiguration.runningContainers:
        runningCTNames.append("%s %s" % (puContainer.id, puContainer.hostname))

    nrRunningCTs = len(runningCTNames) 
    if nrRunningCTs == 0:
        if log.verbosity >= 2:
            log.warning("No PVE/LXC containers seem to be running (names list emtpy).")
        sys.exit(0)

    print("\n".join(runningCTNames));
    
    sys.exit(0)
