'''
  Copyleft ITEG IT-Engineers GmbH 2021,2024
'''

import getopt
#import lxc
#import os
import sys

from iteg.pveutils import dto
from iteg.pveutils import puhelpers
from iteg.pveutils import pulogging

log = pulogging.getLogger()


def describeUsage(argv0):
    usage = ""
    usage += "Usage: %s [options...]\n" % argv0
    usage += "\n"
    usage += "Lists all running PVE/KVM VMs' names to stdout.\n"
    usage += "\n"
    usage += "Do not use -h, --help, -d or -v when processing the output automatically.\n"
    usage += "\n"
    usage += pulogging.getCommonUsageOptions()
    return usage


def run_pu_vms_list(argv0,args):
    try:
        opts, garbage = getopt.getopt(args, "dhqtv", ["help"])
    except getopt.GetoptError as err:
        print(err, file=sys.stderr) # will print something like "option -a not recognized"
        print(describeUsage(argv0), file=sys.stderr)
        sys.exit(64)

    for o, a in opts:
        if o in ["-d", "-q", "-t", "-v"]:
            continue
        elif o in ["-h" , "--help"]:
            print(describeUsage(argv0))
            sys.exit(0)
        else:
            log.warning("Unhandled option: %s %s" % (
                o, a))
    if len(garbage) > 0:
        log.warning("Unhandled options: %s" %
              " ".join(garbage))

    puConfiguration = dto.PUConfiguration()

    if len(puConfiguration.vmsByID) == 0:
        if log.verbosity >= 3:
            log.warning("No PVE/KVM VMs running.")
            sys.exit(0)
    
    knownVMNames = []
    for puVm in puConfiguration.vmsByID.values():
        knownVMNames.append("%s %s" % (puVm.id, puVm.name))

    nrVMs = len(knownVMNames) 
    if nrVMs == 0:
        if log.verbosity >= 2:
            log.warning("No PVE/LXC VMs seem to be known.")
        sys.exit(0)

    print("\n".join(knownVMNames));
    
    sys.exit(0)
